import { EventProcessor, Hub, Integration, Span, SpanContext, SpanStatus } from '@sentry/types';
/** JSDoc */
interface TracingOptions {
    tracingOrigins: Array<string | RegExp>;
    traceFetch: boolean;
    traceXHR: boolean;
    /**
     * This function will be called before creating a span for a request with the given url.
     * Return false if you don't want a span for the given url.
     *
     * By default it uses the `tracingOrigins` options as a url match.
     */
    shouldCreateSpanForRequest(url: string): boolean;
    idleTimeout: number;
    startTransactionOnLocationChange: boolean;
    tracesSampleRate: number;
}
/**
 * Tracing Integration
 */
export declare class Tracing implements Integration {
    private readonly _options?;
    /**
     * @inheritDoc
     */
    name: string;
    /**
     * @inheritDoc
     */
    static id: string;
    /**
     * If we have an xhr we need to store the url in the instance.
     *
     */
    private _xhrUrl?;
    /**
     * Is Tracing enabled, this will be determined once per pageload.
     */
    private static _enabled?;
    /** JSDoc */
    static options: TracingOptions;
    /**
     * Returns current hub.
     */
    private static _getCurrentHub?;
    private static _activeTransaction?;
    private static _currentIndex;
    private static readonly _activities;
    private static _debounce;
    /**
     * Constructor for Tracing
     *
     * @param _options TracingOptions
     */
    constructor(_options?: Partial<TracingOptions> | undefined);
    /**
     * @inheritDoc
     */
    setupOnce(_: (callback: EventProcessor) => void, getCurrentHub: () => Hub): void;
    /**
     * JSDoc
     */
    private _traceXHR;
    /**
     * JSDoc
     */
    private _traceFetch;
    /**
     * Is tracing enabled
     */
    private static _isEnabled;
    /**
     * Starts a Transaction waiting for activity idle to finish
     */
    static startIdleTransaction(name: string, spanContext?: SpanContext): Span | undefined;
    /**
     * Update transaction
     */
    static updateTransactionName(name: string): void;
    /**
     * Finshes the current active transaction
     */
    static finishIdleTransaction(): void;
    /**
     * Sets the status of the current active transaction (if there is one)
     */
    static setTransactionStatus(status: SpanStatus): void;
    /**
     * Starts tracking for a specifc activity
     */
    static pushActivity(name: string, spanContext?: SpanContext): number;
    /**
     * Removes activity and finishes the span in case there is one
     */
    static popActivity(id: number, spanData?: {
        [key: string]: any;
    }): void;
}
export {};
//# sourceMappingURL=tracing.d.ts.map